cd "D:\VHLSS2010\VHLSS2010\Data\Household\"

log using vhlss.smcl, replace

** -- DATA PREPARATION

** -- merge data from different files
*need to sort the data first

use muc1a.dta, clear

sort tinh huyen xa diaban hoso matv

save muc1anew.dta, replace

use muc2.dta, clear

sort tinh huyen xa diaban hoso matv

save muc2new.dta, replace

use muc4a.dta, clear

sort tinh huyen xa diaban hoso matv

save muc4anew.dta, replace

*merge sorted data 
use muc1anew.dta, clear

merge tinh huyen xa diaban hoso matv using muc2new.dta

tab _merge

drop _merge

sort tinh huyen xa diaban hoso matv

merge tinh huyen xa diaban hoso matv using muc4anew.dta

tab _merge

drop _merge

sort tinh huyen xa diaban hoso matv

save muc14.dta, replace

** -- regression with weights

use weight10.dta, clear

sort tinh huyen xa diaban

save weight10.dta, replace

use muc14.dta, clear

merge tinh huyen xa diaban using weight10.dta

tab _merge 

drop _merge

save muc14.dta, replace


** -- DATA ANALYSIS

use muc14.dta, clear

** -- summarize variables

desc

sum

*edit m2c1 m2c2a m2c2b m2c3 m2c4 m2c5 m2c6 m2c7 m2c8

** -- generate variables

*year of education
*m2c1: highest grade
*m2c2a: highest degree

tab m2c1
codebook m2c1
destring m2c1, gen(yoeduc)

replace yoeduc = yoeduc+2 if m2c2a==8 // college
replace yoeduc = yoeduc+4 if m2c2a==9 // university 
replace yoeduc = yoeduc+6 if m2c2a==10 // MA
replace yoeduc = yoeduc+11 if m2c2a==11 // PhD

drop if m2c2a==12 /// others

sum yoeduc


*year of experience = age - 6 - yoeduc

gen yoexper = m1ac5 - 6 - yoeduc

sum yoexper

drop if yoexper < 0

*personal income
*m4ac1a: wage employment
*m4ac11: annual income
*m4ac12a m4ac12b: other income

keep if m4ac1a==1
sum m4ac11 m4ac12a m4ac12b

gen income = m4ac11 + m4ac12a + m4ac12b

*other control variables
*sex (m1ac2), marital (m1ac6), school type (m2c3), type of jobs (m4ac8a, m4ac8b)

codebook m1ac2
gen male = (m1ac2==1)

codebook m1ac6
gen married = (m1ac6==2)

codebook m2c3
gen publicSchool = (m2c3==1)

codebook m4ac8a
gen public = (m4ac8a==5)
gen foreign = (m4ac8a==6)

codebook m4ac8b
gen official = (m4ac8b==1)

** -- manipulate variables
keep income yoeduc yoexper male married publicSchool public foreign official wt9

gen lincome = log(income)

gen yoexpersq = yoexper^2

** -- summarize variables

sum income yoeduc yoexper male married publicSchool public foreign official

sort male

by male: sum income yoeduc yoexper married publicSchool public foreign official

** -- regression analysis

reg lincome yoeduc yoexper yoexpersq married publicSchool public foreign official
est store All

reg lincome yoeduc yoexper yoexpersq married publicSchool public foreign official if male==1
est store Male 

reg lincome yoeduc yoexper yoexpersq married publicSchool public foreign official if male==0
est store Female

*Table out 1
esttab All Male Female, cells(b(star fmt(4)) se(par fmt(4))) ///
legend varlabels(_cons Constant) ///
stats(N r2 r2_a df_r rss, label(Obs R2 R2-adj df(r) SSR)) ///
title(Regression Results) mtitles("All Data" "Male" "Female") nonumbers

*find the optimal year of expericence
reg lincome yoeduc yoexper yoexpersq married publicSchool public foreign official

di -_b[yoexper]/(2*_b[yoexpersq])

graph twoway function y = _b[yoexper]*x + _b[yoexpersq]*x^2, ///
range(0 50) xtitle(year of experience) ytitle(log(income)) xline(25.70)

*adjusting for sample weights

reg lincome yoeduc yoexper yoexpersq married publicSchool public foreign official [pw=1/wt9]
est store All1

reg lincome yoeduc yoexper yoexpersq married publicSchool public foreign official if male==1 [pw=1/wt9]
est store Male1

reg lincome yoeduc yoexper yoexpersq married publicSchool public foreign official if male==0 [pw=1/wt9]
est store Female1

*Table out
esttab All Male Female, cells(b(star fmt(4)) se(par fmt(4))) ///
legend varlabels(_cons Constant) ///
stats(N r2 r2_a df_r rss, label(Obs R2 R2-adj df(r) SSR)) ///
title(Regression Results with Weights) mtitles("All Data" "Male" "Female") nonumbers

** -- sensitivity analysis
*check vif

reg lincome yoeduc yoexper yoexpersq married publicSchool public foreign official

vif

reg lincome yoeduc yoexper married publicSchool public foreign official

vif

*outliers

hist income, normal

hist lincome, normal

*assumptions for BLUE

reg lincome yoeduc yoexper yoexpersq married publicSchool public foreign official

predict uhat, resid

graph twoway (scatter uhat yoeduc, msymbol(x) msize(1)) ///
(function y=0, range(0 25)), legend(label(1 "predicted uhat") ///
label(2 "expected uhat")) graphregion(fcolor(white))

clear

log close
